
# Fretboards

## Horizontal Fretboard

```{eval-rst}
.. automodule:: fretboardgtr.fretboards.horizontal
   :members:
   :undoc-members:
```


## Vertical Fretboard

```{eval-rst}
.. automodule:: fretboardgtr.fretboards.vertical
   :members:
   :undoc-members:
```
